@@ -1,39 +1,32 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.delete_my_organization_response_200 import (
-    DeleteMyOrganizationResponse200,
-)
-from ...types import Response
+from ...client import AuthenticatedClient, Client
+from ...models.api_success_empty import ApiSuccessEmpty
+from ...types import UNSET, Response
 
 
 def _get_kwargs(
     organization_uuid: str,
-    *,
-    client: Client,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/org/{organizationUuid}".format(client.base_url, organizationUuid=organization_uuid)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "delete",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
+        "url": "/api/v1/org/{organizationUuid}".format(
+            organizationUuid=organization_uuid,
+        ),
     }
 
+    return _kwargs
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[DeleteMyOrganizationResponse200]:
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiSuccessEmpty]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = DeleteMyOrganizationResponse200.from_dict(response.json())
+        response_200 = ApiSuccessEmpty.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -42,7 +35,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Del
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[DeleteMyOrganizationResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiSuccessEmpty]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -54,8 +49,8 @@ def _build_response(*, client: Client, response: httpx.Response) -> Response[Del
 def sync_detailed(
     organization_uuid: str,
     *,
-    client: Client,
-) -> Response[DeleteMyOrganizationResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiSuccessEmpty]:
     """Deletes an organization and all users inside that organization
 
     Args:
@@ -66,16 +61,14 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[DeleteMyOrganizationResponse200]
+        Response[ApiSuccessEmpty]
     """
 
     kwargs = _get_kwargs(
         organization_uuid=organization_uuid,
-        client=client,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -85,8 +78,8 @@ def sync_detailed(
 def sync(
     organization_uuid: str,
     *,
-    client: Client,
-) -> Optional[DeleteMyOrganizationResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiSuccessEmpty]:
     """Deletes an organization and all users inside that organization
 
     Args:
@@ -97,7 +90,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        DeleteMyOrganizationResponse200
+        ApiSuccessEmpty
     """
 
     return sync_detailed(
@@ -109,8 +102,8 @@ def sync(
 async def asyncio_detailed(
     organization_uuid: str,
     *,
-    client: Client,
-) -> Response[DeleteMyOrganizationResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiSuccessEmpty]:
     """Deletes an organization and all users inside that organization
 
     Args:
@@ -121,16 +114,14 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[DeleteMyOrganizationResponse200]
+        Response[ApiSuccessEmpty]
     """
 
     kwargs = _get_kwargs(
         organization_uuid=organization_uuid,
-        client=client,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -138,8 +129,8 @@ async def asyncio_detailed(
 async def asyncio(
     organization_uuid: str,
     *,
-    client: Client,
-) -> Optional[DeleteMyOrganizationResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiSuccessEmpty]:
     """Deletes an organization and all users inside that organization
 
     Args:
@@ -150,7 +141,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        DeleteMyOrganizationResponse200
+        ApiSuccessEmpty
     """
 
     return (
