@@ -1,11 +1,14 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
+
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="ApiJobScheduledResponseResults")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ApiJobScheduledResponseResults:
     """
     Attributes:
@@ -13,7 +16,7 @@ class ApiJobScheduledResponseResults:
     """
 
     job_id: str
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         job_id = self.job_id
