@@ -1,9 +1,10 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
 from ..models.scheduler_job_status import SchedulerJobStatus
+from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.record_string_any import RecordStringAny
