@@ -1,36 +1,37 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..models.api_organization_projects_status import ApiOrganizationProjectsStatus
+from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
-    from ..models.api_organization_projects_results_item import (
-        ApiOrganizationProjectsResultsItem,
-    )
+    from ..models.organization_project import OrganizationProject
 
 
 T = TypeVar("T", bound="ApiOrganizationProjects")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ApiOrganizationProjects:
     """List of projects in the current organization
 
     Attributes:
-        results (List['ApiOrganizationProjectsResultsItem']):
+        results (List['OrganizationProject']):
         status (ApiOrganizationProjectsStatus):
     """
 
-    results: List["ApiOrganizationProjectsResultsItem"]
+    results: List["OrganizationProject"]
     status: ApiOrganizationProjectsStatus
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.organization_project import OrganizationProject
+
         results = []
         for results_item_data in self.results:
             results_item = results_item_data.to_dict()
-
             results.append(results_item)
 
         status = self.status.value
@@ -48,15 +49,13 @@ class ApiOrganizationProjects:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.api_organization_projects_results_item import (
-            ApiOrganizationProjectsResultsItem,
-        )
+        from ..models.organization_project import OrganizationProject
 
         d = src_dict.copy()
         results = []
         _results = d.pop("results")
         for results_item_data in _results:
-            results_item = ApiOrganizationProjectsResultsItem.from_dict(results_item_data)
+            results_item = OrganizationProject.from_dict(results_item_data)
 
             results.append(results_item)
 
