@@ -1,8 +1,10 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
+from ..types import UNSET, Unset
+
 if TYPE_CHECKING:
     from ..models.record_string_type_dimension_type import RecordStringTypeDimensionType
     from ..models.record_string_unknown import RecordStringUnknown
@@ -24,6 +26,9 @@ class ApiSqlQueryResults:
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.record_string_type_dimension_type import RecordStringTypeDimensionType
+        from ..models.record_string_unknown import RecordStringUnknown
+
         rows = []
         for rows_item_data in self.rows:
             rows_item = rows_item_data.to_dict()
@@ -44,9 +49,7 @@ class ApiSqlQueryResults:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.record_string_type_dimension_type import (
-            RecordStringTypeDimensionType,
-        )
+        from ..models.record_string_type_dimension_type import RecordStringTypeDimensionType
         from ..models.record_string_unknown import RecordStringUnknown
 
         d = src_dict.copy()
