@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -34,6 +34,11 @@ class CreateUserAttribute:
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.group_attribute_value import GroupAttributeValue
+        from ..models.pick_user_attribute_value_exclude_keyof_user_attribute_value_email import (
+            PickUserAttributeValueExcludeKeyofUserAttributeValueEmail,
+        )
+
         name = self.name
 
         attribute_default: Union[None, str]
