@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -41,6 +41,10 @@ class FunnelChart:
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.funnel_chart_labels import FunnelChartLabels
+        from ..models.record_string_series_metadata import RecordStringSeriesMetadata
+        from ..models.record_string_string import RecordStringString
+
         legend_position: Union[Unset, str] = UNSET
         if not isinstance(self.legend_position, Unset):
             legend_position = self.legend_position.value
