@@ -1,60 +1,62 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.pick_create_trino_credentials_exclude_keyof_create_trino_credentials_sensitive_credentials_field_names_type import (
-    PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNamesType,
-)
+from ..models.warehouse_types_trino import WarehouseTypesTRINO
+from ..models.week_day import WeekDay
 from ..types import UNSET, Unset
 
-if TYPE_CHECKING:
-    from ..models.pick_create_trino_credentials_exclude_keyof_create_trino_credentials_sensitive_credentials_field_names_start_of_week import (
-        PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNamesStartOfWeek,
-    )
-
-
 T = TypeVar("T", bound="PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNames")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNames:
     """From T, pick a set of properties whose keys are in the union K
 
     Attributes:
-        type (PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNamesType):
+        type (WarehouseTypesTRINO):
         schema (str):
         host (str):
         port (float):
         dbname (str):
         http_scheme (str):
-        start_of_week (Union[Unset, None,
-            PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNamesStartOfWeek]):
+        require_user_credentials (Union[Unset, bool]):
+        start_of_week (Union[None, Unset, WeekDay]):
     """
 
-    type: PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNamesType
+    type: WarehouseTypesTRINO
     schema: str
     host: str
     port: float
     dbname: str
     http_scheme: str
-    start_of_week: Union[
-        Unset,
-        None,
-        "PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNamesStartOfWeek",
-    ] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    require_user_credentials: Union[Unset, bool] = UNSET
+    start_of_week: Union[None, Unset, WeekDay] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         type = self.type.value
 
         schema = self.schema
+
         host = self.host
+
         port = self.port
+
         dbname = self.dbname
+
         http_scheme = self.http_scheme
-        start_of_week: Union[Unset, None, Dict[str, Any]] = UNSET
-        if not isinstance(self.start_of_week, Unset):
-            start_of_week = self.start_of_week.to_dict() if self.start_of_week else None
+
+        require_user_credentials = self.require_user_credentials
+
+        start_of_week: Union[None, Unset, int]
+        if isinstance(self.start_of_week, Unset):
+            start_of_week = UNSET
+        elif isinstance(self.start_of_week, WeekDay):
+            start_of_week = self.start_of_week.value
+        else:
+            start_of_week = self.start_of_week
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -68,6 +70,8 @@ class PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCrede
                 "http_scheme": http_scheme,
             }
         )
+        if require_user_credentials is not UNSET:
+            field_dict["requireUserCredentials"] = require_user_credentials
         if start_of_week is not UNSET:
             field_dict["startOfWeek"] = start_of_week
 
@@ -75,14 +79,8 @@ class PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCrede
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.pick_create_trino_credentials_exclude_keyof_create_trino_credentials_sensitive_credentials_field_names_start_of_week import (
-            PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNamesStartOfWeek,
-        )
-
         d = src_dict.copy()
-        type = PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNamesType(
-            d.pop("type")
-        )
+        type = WarehouseTypesTRINO(d.pop("type"))
 
         schema = d.pop("schema")
 
@@ -94,20 +92,24 @@ class PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCrede
 
         http_scheme = d.pop("http_scheme")
 
-        _start_of_week = d.pop("startOfWeek", UNSET)
-        start_of_week: Union[
-            Unset,
-            None,
-            PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNamesStartOfWeek,
-        ]
-        if _start_of_week is None:
-            start_of_week = None
-        elif isinstance(_start_of_week, Unset):
-            start_of_week = UNSET
-        else:
-            start_of_week = PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCredentialsFieldNamesStartOfWeek.from_dict(
-                _start_of_week
-            )
+        require_user_credentials = d.pop("requireUserCredentials", UNSET)
+
+        def _parse_start_of_week(data: object) -> Union[None, Unset, WeekDay]:
+            if data is None:
+                return data
+            if isinstance(data, Unset):
+                return data
+            try:
+                if not isinstance(data, int):
+                    raise TypeError()
+                start_of_week_type_1 = WeekDay(data)
+
+                return start_of_week_type_1
+            except:  # noqa: E722
+                pass
+            return cast(Union[None, Unset, WeekDay], data)
+
+        start_of_week = _parse_start_of_week(d.pop("startOfWeek", UNSET))
 
         pick_create_trino_credentials_exclude_keyof_create_trino_credentials_sensitive_credentials_field_names = cls(
             type=type,
@@ -116,12 +118,11 @@ class PickCreateTrinoCredentialsExcludeKeyofCreateTrinoCredentialsSensitiveCrede
             port=port,
             dbname=dbname,
             http_scheme=http_scheme,
+            require_user_credentials=require_user_credentials,
             start_of_week=start_of_week,
         )
 
-        pick_create_trino_credentials_exclude_keyof_create_trino_credentials_sensitive_credentials_field_names.additional_properties = (
-            d
-        )
+        pick_create_trino_credentials_exclude_keyof_create_trino_credentials_sensitive_credentials_field_names.additional_properties = d
         return pick_create_trino_credentials_exclude_keyof_create_trino_credentials_sensitive_credentials_field_names
 
     @property
