@@ -1,20 +1,22 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.project_member_profile_role import ProjectMemberProfileRole
+from ..models.project_member_role import ProjectMemberRole
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="ProjectMemberProfile")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ProjectMemberProfile:
     """
     Attributes:
         last_name (str):
         first_name (str):
         email (str):
-        role (ProjectMemberProfileRole):
+        role (ProjectMemberRole):
         project_uuid (str):
         user_uuid (str):
     """
@@ -22,18 +24,22 @@ class ProjectMemberProfile:
     last_name: str
     first_name: str
     email: str
-    role: ProjectMemberProfileRole
+    role: ProjectMemberRole
     project_uuid: str
     user_uuid: str
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         last_name = self.last_name
+
         first_name = self.first_name
+
         email = self.email
+
         role = self.role.value
 
         project_uuid = self.project_uuid
+
         user_uuid = self.user_uuid
 
         field_dict: Dict[str, Any] = {}
@@ -60,7 +66,7 @@ class ProjectMemberProfile:
 
         email = d.pop("email")
 
-        role = ProjectMemberProfileRole(d.pop("role"))
+        role = ProjectMemberRole(d.pop("role"))
 
         project_uuid = d.pop("projectUuid")
 
