@@ -1,149 +1,175 @@
 import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
-from ..models.resource_view_chart_item_data_chart_type import (
-    ResourceViewChartItemDataChartType,
-)
+from ..models.chart_kind import ChartKind
+from ..models.chart_source_type import ChartSourceType
+from ..models.chart_type import ChartType
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
-    from ..models.resource_view_chart_item_data_updated_by_user import (
-        ResourceViewChartItemDataUpdatedByUser,
-    )
-    from ..models.resource_view_chart_item_data_validation_errors_item import (
-        ResourceViewChartItemDataValidationErrorsItem,
+    from ..models.pick_validation_response_error_or_created_at_or_validation_id import (
+        PickValidationResponseErrorOrCreatedAtOrValidationId,
     )
+    from ..models.updated_by_user import UpdatedByUser
 
 
 T = TypeVar("T", bound="ResourceViewChartItemData")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ResourceViewChartItemData:
-    """From T, pick a set of properties whose keys are in the union K
-
+    """
     Attributes:
         name (str):
         uuid (str):
-        updated_at (datetime.datetime):
         space_uuid (str):
+        pinned_list_uuid (Union[None, str]):
+        slug (str):
+        updated_at (datetime.datetime):
         views (float):
-        description (Union[Unset, str]):
-        updated_by_user (Union[Unset, ResourceViewChartItemDataUpdatedByUser]):
         first_viewed_at (Union[None, datetime.datetime, str]):
-        pinned_list_uuid (Optional[str]):
-        pinned_list_order (Optional[float]):
-        validation_errors (Union[Unset, List['ResourceViewChartItemDataValidationErrorsItem']]):
-        chart_type (Union[Unset, ResourceViewChartItemDataChartType]):
+        pinned_list_order (Union[None, float]):
+        description (Union[Unset, str]):
+        chart_kind (Union[Unset, ChartKind]):
+        updated_by_user (Union[Unset, UpdatedByUser]):
+        validation_errors (Union[Unset, List['PickValidationResponseErrorOrCreatedAtOrValidationId']]):
+        chart_type (Union[Unset, ChartType]):
+        source (Union[Unset, ChartSourceType]):
     """
 
     name: str
     uuid: str
-    updated_at: datetime.datetime
     space_uuid: str
+    pinned_list_uuid: Union[None, str]
+    slug: str
+    updated_at: datetime.datetime
     views: float
     first_viewed_at: Union[None, datetime.datetime, str]
-    pinned_list_uuid: Optional[str]
-    pinned_list_order: Optional[float]
+    pinned_list_order: Union[None, float]
     description: Union[Unset, str] = UNSET
-    updated_by_user: Union[Unset, "ResourceViewChartItemDataUpdatedByUser"] = UNSET
-    validation_errors: Union[Unset, List["ResourceViewChartItemDataValidationErrorsItem"]] = UNSET
-    chart_type: Union[Unset, ResourceViewChartItemDataChartType] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    chart_kind: Union[Unset, ChartKind] = UNSET
+    updated_by_user: Union[Unset, "UpdatedByUser"] = UNSET
+    validation_errors: Union[Unset, List["PickValidationResponseErrorOrCreatedAtOrValidationId"]] = UNSET
+    chart_type: Union[Unset, ChartType] = UNSET
+    source: Union[Unset, ChartSourceType] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.pick_validation_response_error_or_created_at_or_validation_id import (
+            PickValidationResponseErrorOrCreatedAtOrValidationId,
+        )
+        from ..models.updated_by_user import UpdatedByUser
+
         name = self.name
+
         uuid = self.uuid
-        updated_at = self.updated_at.isoformat()
 
         space_uuid = self.space_uuid
+
+        pinned_list_uuid: Union[None, str]
+        pinned_list_uuid = self.pinned_list_uuid
+
+        slug = self.slug
+
+        updated_at = self.updated_at.isoformat()
+
         views = self.views
+
+        first_viewed_at: Union[None, str]
+        if isinstance(self.first_viewed_at, datetime.datetime):
+            first_viewed_at = self.first_viewed_at.isoformat()
+        else:
+            first_viewed_at = self.first_viewed_at
+
+        pinned_list_order: Union[None, float]
+        pinned_list_order = self.pinned_list_order
+
         description = self.description
+
+        chart_kind: Union[Unset, str] = UNSET
+        if not isinstance(self.chart_kind, Unset):
+            chart_kind = self.chart_kind.value
+
         updated_by_user: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.updated_by_user, Unset):
             updated_by_user = self.updated_by_user.to_dict()
 
-        first_viewed_at: Union[None, str]
-        if self.first_viewed_at is None:
-            first_viewed_at = None
-
-        elif isinstance(self.first_viewed_at, datetime.datetime):
-            first_viewed_at = self.first_viewed_at.isoformat()
-
-        else:
-            first_viewed_at = self.first_viewed_at
-
-        pinned_list_uuid = self.pinned_list_uuid
-        pinned_list_order = self.pinned_list_order
         validation_errors: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.validation_errors, Unset):
             validation_errors = []
             for validation_errors_item_data in self.validation_errors:
                 validation_errors_item = validation_errors_item_data.to_dict()
-
                 validation_errors.append(validation_errors_item)
 
         chart_type: Union[Unset, str] = UNSET
         if not isinstance(self.chart_type, Unset):
             chart_type = self.chart_type.value
 
+        source: Union[Unset, str] = UNSET
+        if not isinstance(self.source, Unset):
+            source = self.source.value
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
             {
                 "name": name,
                 "uuid": uuid,
-                "updatedAt": updated_at,
                 "spaceUuid": space_uuid,
+                "pinnedListUuid": pinned_list_uuid,
+                "slug": slug,
+                "updatedAt": updated_at,
                 "views": views,
                 "firstViewedAt": first_viewed_at,
-                "pinnedListUuid": pinned_list_uuid,
                 "pinnedListOrder": pinned_list_order,
             }
         )
         if description is not UNSET:
             field_dict["description"] = description
+        if chart_kind is not UNSET:
+            field_dict["chartKind"] = chart_kind
         if updated_by_user is not UNSET:
             field_dict["updatedByUser"] = updated_by_user
         if validation_errors is not UNSET:
             field_dict["validationErrors"] = validation_errors
         if chart_type is not UNSET:
             field_dict["chartType"] = chart_type
+        if source is not UNSET:
+            field_dict["source"] = source
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.resource_view_chart_item_data_updated_by_user import (
-            ResourceViewChartItemDataUpdatedByUser,
-        )
-        from ..models.resource_view_chart_item_data_validation_errors_item import (
-            ResourceViewChartItemDataValidationErrorsItem,
+        from ..models.pick_validation_response_error_or_created_at_or_validation_id import (
+            PickValidationResponseErrorOrCreatedAtOrValidationId,
         )
+        from ..models.updated_by_user import UpdatedByUser
 
         d = src_dict.copy()
         name = d.pop("name")
 
         uuid = d.pop("uuid")
 
-        updated_at = isoparse(d.pop("updatedAt"))
-
         space_uuid = d.pop("spaceUuid")
 
+        def _parse_pinned_list_uuid(data: object) -> Union[None, str]:
+            if data is None:
+                return data
+            return cast(Union[None, str], data)
+
+        pinned_list_uuid = _parse_pinned_list_uuid(d.pop("pinnedListUuid"))
+
+        slug = d.pop("slug")
+
+        updated_at = isoparse(d.pop("updatedAt"))
+
         views = d.pop("views")
 
-        description = d.pop("description", UNSET)
-
-        _updated_by_user = d.pop("updatedByUser", UNSET)
-        updated_by_user: Union[Unset, ResourceViewChartItemDataUpdatedByUser]
-        if isinstance(_updated_by_user, Unset):
-            updated_by_user = UNSET
-        else:
-            updated_by_user = ResourceViewChartItemDataUpdatedByUser.from_dict(_updated_by_user)
-
         def _parse_first_viewed_at(data: object) -> Union[None, datetime.datetime, str]:
             if data is None:
                 return data
@@ -159,39 +185,68 @@ class ResourceViewChartItemData:
 
         first_viewed_at = _parse_first_viewed_at(d.pop("firstViewedAt"))
 
-        pinned_list_uuid = d.pop("pinnedListUuid")
+        def _parse_pinned_list_order(data: object) -> Union[None, float]:
+            if data is None:
+                return data
+            return cast(Union[None, float], data)
 
-        pinned_list_order = d.pop("pinnedListOrder")
+        pinned_list_order = _parse_pinned_list_order(d.pop("pinnedListOrder"))
+
+        description = d.pop("description", UNSET)
+
+        _chart_kind = d.pop("chartKind", UNSET)
+        chart_kind: Union[Unset, ChartKind]
+        if isinstance(_chart_kind, Unset):
+            chart_kind = UNSET
+        else:
+            chart_kind = ChartKind(_chart_kind)
+
+        _updated_by_user = d.pop("updatedByUser", UNSET)
+        updated_by_user: Union[Unset, UpdatedByUser]
+        if isinstance(_updated_by_user, Unset):
+            updated_by_user = UNSET
+        else:
+            updated_by_user = UpdatedByUser.from_dict(_updated_by_user)
 
         validation_errors = []
         _validation_errors = d.pop("validationErrors", UNSET)
         for validation_errors_item_data in _validation_errors or []:
-            validation_errors_item = ResourceViewChartItemDataValidationErrorsItem.from_dict(
+            validation_errors_item = PickValidationResponseErrorOrCreatedAtOrValidationId.from_dict(
                 validation_errors_item_data
             )
 
             validation_errors.append(validation_errors_item)
 
         _chart_type = d.pop("chartType", UNSET)
-        chart_type: Union[Unset, ResourceViewChartItemDataChartType]
+        chart_type: Union[Unset, ChartType]
         if isinstance(_chart_type, Unset):
             chart_type = UNSET
         else:
-            chart_type = ResourceViewChartItemDataChartType(_chart_type)
+            chart_type = ChartType(_chart_type)
+
+        _source = d.pop("source", UNSET)
+        source: Union[Unset, ChartSourceType]
+        if isinstance(_source, Unset):
+            source = UNSET
+        else:
+            source = ChartSourceType(_source)
 
         resource_view_chart_item_data = cls(
             name=name,
             uuid=uuid,
-            updated_at=updated_at,
             space_uuid=space_uuid,
-            views=views,
-            description=description,
-            updated_by_user=updated_by_user,
-            first_viewed_at=first_viewed_at,
             pinned_list_uuid=pinned_list_uuid,
+            slug=slug,
+            updated_at=updated_at,
+            views=views,
+            first_viewed_at=first_viewed_at,
             pinned_list_order=pinned_list_order,
+            description=description,
+            chart_kind=chart_kind,
+            updated_by_user=updated_by_user,
             validation_errors=validation_errors,
             chart_type=chart_type,
+            source=source,
         )
 
         resource_view_chart_item_data.additional_properties = d
