@@ -1,8 +1,10 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
+from ..types import UNSET, Unset
+
 if TYPE_CHECKING:
     from ..models.dashboard_basic_details import DashboardBasicDetails
     from ..models.space_group import SpaceGroup
@@ -46,6 +48,11 @@ class Space:
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.dashboard_basic_details import DashboardBasicDetails
+        from ..models.space_group import SpaceGroup
+        from ..models.space_query import SpaceQuery
+        from ..models.space_share import SpaceShare
+
         slug = self.slug
 
         pinned_list_order: Union[None, float]
