@@ -1,55 +1,54 @@
 import datetime
-from typing import Any
-from typing import Dict
-from typing import List
-from typing import Type
-from typing import TypeVar
-from typing import Union
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
-from ..models.validation_response_base_error_type import ValidationResponseBaseErrorType
-from ..models.validation_response_base_source import ValidationResponseBaseSource
-from ..types import UNSET
-from ..types import Unset
+from ..models.validation_error_type import ValidationErrorType
+from ..models.validation_source_type import ValidationSourceType
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="ValidationResponseBase")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ValidationResponseBase:
     """
     Attributes:
         project_uuid (str):
-        error_type (ValidationResponseBaseErrorType):
+        error_type (ValidationErrorType):
         error (str):
         name (str):
         created_at (datetime.datetime):
         validation_id (float):
-        source (Union[Unset, ValidationResponseBaseSource]):
+        source (Union[Unset, ValidationSourceType]):
         space_uuid (Union[Unset, str]):
     """
 
     project_uuid: str
-    error_type: ValidationResponseBaseErrorType
+    error_type: ValidationErrorType
     error: str
     name: str
     created_at: datetime.datetime
     validation_id: float
-    source: Union[Unset, ValidationResponseBaseSource] = UNSET
+    source: Union[Unset, ValidationSourceType] = UNSET
     space_uuid: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         project_uuid = self.project_uuid
+
         error_type = self.error_type.value
 
         error = self.error
+
         name = self.name
+
         created_at = self.created_at.isoformat()
 
         validation_id = self.validation_id
+
         source: Union[Unset, str] = UNSET
         if not isinstance(self.source, Unset):
             source = self.source.value
@@ -80,7 +79,7 @@ class ValidationResponseBase:
         d = src_dict.copy()
         project_uuid = d.pop("projectUuid")
 
-        error_type = ValidationResponseBaseErrorType(d.pop("errorType"))
+        error_type = ValidationErrorType(d.pop("errorType"))
 
         error = d.pop("error")
 
@@ -91,11 +90,11 @@ class ValidationResponseBase:
         validation_id = d.pop("validationId")
 
         _source = d.pop("source", UNSET)
-        source: Union[Unset, ValidationResponseBaseSource]
+        source: Union[Unset, ValidationSourceType]
         if isinstance(_source, Unset):
             source = UNSET
         else:
-            source = ValidationResponseBaseSource(_source)
+            source = ValidationSourceType(_source)
 
         space_uuid = d.pop("spaceUuid", UNSET)
 
